@@ -5,7 +5,7 @@
 from __future__ import annotations
 
 import dataclasses
-import subprocess
+import subprocess  # noqa: S404
 import sys
 from typing import TYPE_CHECKING
 
@@ -79,7 +79,9 @@ def _tox_get_envs(cfg: cmd.Config) -> list[cmd.TestEnv]:
     if cfg.tox_program is None:
         sys.exit("No tox program found or specified")
     tcfg: Final = ttt_parse.parse_showconfig(
-        filename=cfg.filename, env=cfg.utf8_env, tox_invoke=cfg.tox_program
+        filename=cfg.filename,
+        env=cfg.utf8_env,
+        tox_invoke=cfg.tox_program,
     )
     return [cmd.TestEnv(name, env.tags) for name, env in tcfg.items()]
 
@@ -116,5 +118,4 @@ main.add_command(_cmd_run)
 
 
 if __name__ == "__main__":
-    # pylint: disable-next=no-value-for-parameter
     main()
