@@ -7,47 +7,35 @@ Inspired by https://github.com/tox-dev/tox-tags
 
 from __future__ import annotations
 
-import logging
+import importlib.metadata
 import typing
 
-import distlib.database as dist_database
-import distlib.version as dist_version
+import packaging.version as pver
 
 
 if typing.TYPE_CHECKING:
     from typing import Final
 
 
-def _get_tox_distribution() -> dist_database.InstalledDistribution | None:
-    """Figure out whether Tox is installed."""
+def _get_tox_version() -> str | None:
+    """Figure out which version of Tox is installed."""
+    try:
+        dist: Final = importlib.metadata.metadata("tox")
+    except ModuleNotFoundError:
+        return None
 
-    def no_messages(_evt: logging.LogRecord) -> bool:
-        """Do not output any logging messages, none at all."""
-        return False
-
-    logging.getLogger("distlib.database").addFilter(no_messages)
-    logging.getLogger("distlib.metadata").addFilter(no_messages)
-    dist: Final = dist_database.DistributionPath(include_egg=True).get_distribution("tox")
-    logging.getLogger("distlib.database").removeFilter(no_messages)
-    logging.getLogger("distlib.metadata").removeFilter(no_messages)
-    return dist
+    return dist.get("Version")
 
 
-_TOX_DIST: Final = _get_tox_distribution()
+_TOX_VERSION: Final = _get_tox_version()
 
-if _TOX_DIST is None:
+if _TOX_VERSION is None:
     HAVE_MOD_TOX_3 = False
     HAVE_MOD_TOX_4 = False
 else:
-    _TOX_VERSION: Final = dist_version.NormalizedVersion(_TOX_DIST.version)
+    HAVE_MOD_TOX_3 = pver.Version("3") <= pver.Version(_TOX_VERSION) < pver.Version("4")
 
-    HAVE_MOD_TOX_3 = (
-        dist_version.NormalizedVersion("3") <= _TOX_VERSION < dist_version.NormalizedVersion("4")
-    )
-
-    HAVE_MOD_TOX_4 = (
-        dist_version.NormalizedVersion("4") <= _TOX_VERSION < dist_version.NormalizedVersion("5")
-    )
+    HAVE_MOD_TOX_4 = pver.Version("4") <= pver.Version(_TOX_VERSION) < pver.Version("5")
 
 
 if HAVE_MOD_TOX_3:
@@ -58,7 +46,10 @@ if HAVE_MOD_TOX_3:
     def tox_addoption(parser: tox.config.Parser) -> None:
         """Parse a testenv's "tags" attribute as a list of lines."""
         parser.add_testenv_attribute(
-            "tags", "line-list", "A list of tags describing this test environment", default=[]
+            "tags",
+            "line-list",
+            "A list of tags describing this test environment",
+            default=[],
         )
 
 
