@@ -8,8 +8,9 @@ from __future__ import annotations
 
 import ast
 import configparser
+import itertools
 import pathlib
-import subprocess
+import subprocess  # noqa: S404
 import sys
 from typing import Final, NamedTuple
 
@@ -64,6 +65,11 @@ def _parse_lines(value: str) -> list[str]:
     return [line for line in value.splitlines() if line]
 
 
+def _parse_tags(value: str) -> list[str]:
+    """Invoke `_parse_lines()` or `_parse_strlist()` as appropriate."""
+    return _parse_strlist(value) if value.lstrip().startswith("[") else _parse_lines(value)
+
+
 def remove_prefix(value: str, prefix: str) -> str:
     """Remove a string's prefix if it is there.
 
@@ -90,31 +96,46 @@ def parse_showconfig(
         "-e",
         "ALL",
     ]
-    contents: Final = subprocess.run(
-        tox_cmd,
-        check=True,
-        encoding="UTF-8",
-        env=env,
-        shell=False,  # noqa: S603
-        stdout=subprocess.PIPE,
-    ).stdout
-    assert isinstance(contents, str)
 
-    cfgp: Final = configparser.ConfigParser(interpolation=None)
-    cfgp.read_string(contents)
+    def parse_output() -> configparser.ConfigParser:
+        """Run Tox, parse its output as an INI-style file."""
+        lines: Final = subprocess.run(
+            tox_cmd,
+            check=True,
+            encoding="UTF-8",
+            env=env,
+            shell=False,  # noqa: S603
+            stdout=subprocess.PIPE,
+        ).stdout.splitlines()
+        # Drop the lines that Tox outputs at the start if it needs to bootstrap
+        # a more recent version due to a `tox.minversion` specification.
+        lines_real: Final = itertools.dropwhile(lambda line: not line.startswith("["), lines)
 
-    return {
-        name: TestenvTags(
-            cfg_name=cfg_name,
-            name=name,
-            tags=_parse_strlist(tags) if HAVE_MOD_TOX_3 else _parse_lines(tags),
-        )
-        for cfg_name, name, tags in (
-            (cfg_name, name, env["tags"])
-            for cfg_name, name, env in (
-                (cfg_name, remove_prefix(cfg_name, "testenv:"), env)
-                for cfg_name, env in cfgp.items()
+        cfgp: Final = configparser.ConfigParser(interpolation=None)
+        cfgp.read_string("\n".join(lines_real) + "\n")
+        return cfgp
+
+    def process_config(cfgp: configparser.ConfigParser) -> dict[str, TestenvTags]:
+        """Build the result dictionary."""
+        return {
+            name: TestenvTags(
+                cfg_name=cfg_name,
+                name=name,
+                tags=_parse_tags(tags),
             )
-            if cfg_name != name
-        )
-    }
+            for cfg_name, name, tags in (
+                (cfg_name, name, env["tags"])
+                for cfg_name, name, env in (
+                    (cfg_name, remove_prefix(cfg_name, "testenv:"), env)
+                    for cfg_name, env in cfgp.items()
+                )
+                if cfg_name != name
+            )
+        }
+
+    cfgp_no_req: Final = parse_output()
+    if any("tags" in env for env in cfgp_no_req.values()):
+        return process_config(cfgp_no_req)
+
+    tox_cmd.extend(["-x", "tox.requires=test-stages >= 0.1.3"])
+    return process_config(parse_output())
